@@ -47,9 +47,12 @@
 #'                    is emptied. This is to reduce RAM load of large return object.
 #'                    Default FALSE.
 #'
-#' @param ... Passed to \code{spades}. Specifically, \code{debug}, \code{.plotInitialTime}, or
-#'            \code{.saveInitialTime}.
+#' @param ... Passed to \code{spades}. Specifically, \code{debug}, \code{.plotInitialTime},
+#'            \code{.saveInitialTime}, \code{cache} and/or \code{notOlderThan}. Caching
+#'            is still experimental. It is tested to work under some conditions, but not
+#'            all. See details.
 #'
+#' @inheritParams spades
 #' @details
 #' This function requires a complete simList: this simList will form the basis of the
 #' modifications as passed by params, modules, inputs, and objects.
@@ -138,6 +141,18 @@
 #' \code{substrLength}, if \code{0}, will eliminate the subfolder naming convention and use
 #' only \code{dirPrefix}.
 #'
+#' If \code{cache = TRUE} is passed, then this will pass this to \code{spades}, with the
+#' additional argument \code{replicate = x}, where x is the replicate number. That means that
+#' if a user runs \code{experiment} with \code{replicate = 4} and \code{cache = TRUE}, then spades
+#' will run 4 replicates, caching the results, including replicate = 1, replicate = 2, replicate = 3,
+#' and replicate = 4. Thus, if a second call to experiment with the exact same simList is passed,
+#' and \code{replicates = 6}, the first 4 will be taken from the cached copies, and replicate 5 and
+#' 6 will be run (and cached) as normal. If \code{notOlderThan} used with a time that is more recent
+#' than the cached copy, then a new spades will be done, and the cached copy will be deleted from
+#' the cache repository, so there will only ever be one copy of a particular replicate for a
+#' particular simList. NOTE: caching may not work as desired on a Windows machine because
+#' the sqlite database can only be written to one at a time, so there may be collisions.
+#'
 #' @return Invisibly returns a list of the resulting \code{simList} objects from the fully
 #' factorial experiment. This list has an attribute, which a list with 2 elements:
 #' the experimental design provided in a wide data.frame and the experiment values
@@ -200,16 +215,16 @@
 #'   # Read in outputs from sims object
 #'   FireMaps <- do.call(stack, lapply(1:NROW(attr(sims, "experiment")$expDesign),
 #'                      function(x) sims[[x]]$landscape$Fires))
-#'   Plot(FireMaps, new = TRUE)
+#'   if (interactive()) Plot(FireMaps, new = TRUE)
 #'
 #'   # Or reload objects from files, useful if sim objects too large to store in RAM
 #'   caribouMaps <- lapply(sims, function(sim) {
 #'     caribou <- readRDS(outputs(sim)$file[outputs(sim)$objectName == "caribou"])
-#'     })
+#'   })
 #'   names(caribouMaps) <- paste0("caribou",1:8)
 #'   # Plot does not plot whole lists (yet)
-#'   for(i in 1:NROW(attr(sims,"experiment")$expDesign)){
-#'     Plot(caribouMaps[[i]], size = 0.1)}
+#'   for (i in 1:NROW(attr(sims,"experiment")$expDesign)) {
+#'     if (interactive()) Plot(caribouMaps[[i]], size = 0.1)}
 #'
 #' # Example 2 - test alternative modules
 #'   # Example of changing modules, i.e., caribou with and without fires
@@ -313,7 +328,7 @@
 #'   Fires <- lapply(landscapeFiles, function(x) readRDS(x)$Fires) %>% stack
 #'   Fires[Fires > 0] <- 1 # convert to 1s and 0s
 #'   fireProb <- sum(Fires)/nlayers(Fires) # sum them and convert to probability
-#'   Plot(fireProb, new = TRUE)
+#'   if (interactive()) Plot(fireProb, new = TRUE)
 #'
 #' # Example 9 - Pass in inputs, i.e., input data objects taken from disk
 #'   #  Here, we, again, don't provide randomLandscapes module, so we need to
@@ -383,8 +398,9 @@ setGeneric(
   "experiment",
   function(sim, replicates = 1, params, modules, objects = list(), inputs,
            dirPrefix = "simNum", substrLength = 3, saveExperiment = TRUE,
-           experimentFile = "experiment.RData", clearSimEnv = FALSE, ...) {
-  standardGeneric("experiment")
+           experimentFile = "experiment.RData", clearSimEnv = FALSE, notOlderThan,
+           ...) {
+    standardGeneric("experiment")
 })
 
 #' @rdname experiment
@@ -393,7 +409,7 @@ setMethod(
   signature(sim = "simList"),
   definition = function(sim, replicates, params, modules, objects, inputs,
                         dirPrefix, substrLength, saveExperiment,
-                        experimentFile, clearSimEnv, ...) {
+                        experimentFile, clearSimEnv, notOlderThan, ...) {
 
     if (missing(params)) params <- list()
     if (missing(modules)) modules <- list(unlist(SpaDES::modules(sim)[-(1:4)]))
@@ -514,7 +530,7 @@ setMethod(
                   object = if ((mod[x] %in% c("object"))) names(objects)[[factorialExp[ind, "object"]]] else NA,
                   expLevel = factorialExp[ind, "expLevel"],
                   stringsAsFactors = FALSE
-              )),
+                )),
               use.names = TRUE,
               fill = TRUE)
           }
@@ -525,7 +541,7 @@ setMethod(
               data.frame(modules = paste0(unlist(modules[factorialExp[ind, "modules"]]), collapse = ","),
                          expLevel = factorialExp[ind,"expLevel"],
                          stringsAsFactors = FALSE
-            )),
+              )),
             use.names = TRUE,
             fill = TRUE)
         }
@@ -598,7 +614,17 @@ setMethod(
                                    split = "\\.")[[1]][1]
         sim_[[replaceObjName]] <- objects[[factorialExp[ind, "object"]]]
       }
-      sim3 <- spades(sim_, ...)
+
+      dots <- list(...)
+      if (is.null(dots$cache)) dots$cache <- FALSE
+      if (dots$cache) {
+        if (is(try(archivist::showLocalRepo(paths(sim_)$cachePath), silent = TRUE), "try-error"))
+          archivist::createLocalRepo(paths(sim_)$cachePath)
+        sim3 <- (SpaDES::cache(cacheRepo = paths(sim_)$cachePath, spades, sim = sim_,
+                               progress = NA, debug = FALSE, replicate = ind, ...))
+      } else {
+        sim3 <- spades(sim_, ...)
+      }
       return(list(sim3, experimentDF))
     }
 
@@ -613,6 +639,11 @@ setMethod(
       parFun <- "lapply"
       args <- list(X = 1:NROW(factorialExp), FUN = FunDef)
     }
+    dots <- list(...)
+    args <- append(args, dots)
+    if (missing(notOlderThan)) notOlderThan <- NULL
+    li <- list(notOlderThan = notOlderThan)
+    args <- append(args, li)
 
     expOut <- do.call(get(parFun), args)
     sims <- lapply(expOut, function(x) x[[1]])
@@ -626,7 +657,7 @@ setMethod(
                                            "modules"[length(modules) > 1],
                                            "val"[length(params) > 1])
 
-    experimentDF <- experimentDF[,keepCols]
+    experimentDF <- experimentDF[, keepCols]
 
 
     experiment <- list(expDesign = factorialExp, expVals = experimentDF)
@@ -642,4 +673,4 @@ setMethod(
     })
     }
     return(invisible(sims))
-  })
+})
