@@ -81,7 +81,7 @@ doEvent.save <- function(sim, eventTime, eventType, debug = FALSE) {
 #' \dontrun{
 #'  sim <- saveFiles(mySim)
 #' }
-saveFiles = function(sim) {
+saveFiles <- function(sim) {
   curTime <- time(sim, timeunit(sim))
   # extract the current module name that called this function
   moduleName <- currentModule(sim)
@@ -97,20 +97,22 @@ saveFiles = function(sim) {
   }
 
   if (NROW(outputs(sim)[outputs(sim)$saveTime == curTime & is.na(outputs(sim)$saved), "saved"]) > 0) {
-
     wh <- which(outputs(sim)$saveTime == curTime & is.na(outputs(sim)$saved))
     for (i in wh) {
-      if (exists(outputs(sim)[i,"objectName"], envir = envir(sim))) {
+      if (exists(outputs(sim)[i, "objectName"], envir = envir(sim))) {
         args <- append(list(get(outputs(sim)[i, "objectName"], envir = envir(sim)),
-                     file = outputs(sim)[i, "file"]),
-                     outputArgs(sim)[[i]])
+                            file = outputs(sim)[i, "file"]),
+                       outputArgs(sim)[[i]])
         args <- args[!sapply(args, is.null)]
+        args <- suppressWarnings(args[!unlist(lapply(args, function(j) {
+          isTRUE(tryCatch(is.na(j), error = function(e) FALSE))
+        }))])
 
         # The actual save line
-        do.call(outputs(sim)[i,"fun"], args = args,
-                envir=getNamespace(outputs(sim)[i,"package"]))
+        do.call(outputs(sim)[i, "fun"], args = args,
+                envir = getNamespace(outputs(sim)[i, "package"]))
 
-        outputs(sim)[i,"saved"] <- TRUE
+        outputs(sim)[i, "saved"] <- TRUE
       } else {
         warning(paste(outputs(sim)$obj[i],
                       "is not an object in the simList. Cannot save."))
@@ -120,8 +122,8 @@ saveFiles = function(sim) {
   }
 
   # Schedule an event for the next time in the saveTime column
-  if (any(is.na(outputs(sim)[outputs(sim)$saveTime > curTime,"saved"]))) {
-    nextTime <- min(outputs(sim)[is.na(outputs(sim)$saved),"saveTime"], na.rm = TRUE)
+  if (any(is.na(outputs(sim)[outputs(sim)$saveTime > curTime, "saved"]))) {
+    nextTime <- min(outputs(sim)[is.na(outputs(sim)$saved), "saveTime"], na.rm = TRUE)
     attributes(nextTime)$unit <- timeunit(sim)
     sim <- scheduleEvent(sim, nextTime, "save", "later", .last())
   }
