@@ -57,7 +57,7 @@
 #' # if the user wants to see the events go by, which can help with debugging:
 #' shine(mySim, debug=TRUE)
 #' }
-setGeneric("shine", function(sim, title="SpaDES App", debug=FALSE, ...) {
+setGeneric("shine", function(sim, title = "SpaDES App", debug = FALSE, ...) {
   standardGeneric("shine")
 })
 
@@ -65,7 +65,7 @@ setGeneric("shine", function(sim, title="SpaDES App", debug=FALSE, ...) {
 #' @rdname shine
 setMethod(
   "shine",
-  signature= signature(sim = "simList"),
+  signature = signature(sim = "simList"),
   definition = function(sim, title, debug, ...) {
 
   # Keep a copy of input simList so Reset button works
@@ -91,7 +91,7 @@ setMethod(
         uiOutput("moduleTabs")
       ),
       mainPanel(
-        tabsetPanel(id="topTabsetPanel",
+        tabsetPanel(id = "topTabsetPanel",
           tabPanel("Preview", plotOutput("spadesPlot", height = "800px")),
           tabPanel("Module diagram", uiOutput("moduleDiagramUI")),
           tabPanel("Object diagram", uiOutput("objectDiagramUI")),
@@ -99,7 +99,6 @@ setMethod(
           tabPanel("Object browser", uiOutput("objectBrowserUI")),
           tabPanel("Inputs loaded", uiOutput("inputObjectsUI"))
         )
-
       )
     )
   )
@@ -148,8 +147,8 @@ setMethod(
                 min = params(sim)[[kLocal]][[i]]*0.5,
                 max = params(sim)[[kLocal]][[i]]*2,
                 value = params(sim)[[kLocal]][[i]],
-                step =(params(sim)[[kLocal]][[i]]*2 - params(sim)[[kLocal]][[i]]*0.5)/10,
-                sep="")
+                step = (params(sim)[[kLocal]][[i]]*2 - params(sim)[[kLocal]][[i]]*0.5)/10,
+                sep = "")
             } else if (is.logical(Params[[i]])) {
               checkboxInput(
                 inputId = paste0(kLocal, "$", i),
@@ -159,7 +158,6 @@ setMethod(
             # To do make ones for logical, character, functions, text etc.
           })
         })
-
       })
     }
 
@@ -172,9 +170,9 @@ setMethod(
             params(sim)[[m]][[i]] <- input[[paste0(m, "$", i)]]
         }
       }
-      end(sim) <- pmin(endTime, time(sim) + 1)
+      end(sim) <- pmin(endTime, time(sim, timeunit(sim)) + 1)
       if (is.null(v$stop)) {v$stop = "go"}
-      if ((time(sim) < endTime) & (v$stop != "stop")) invalidateLater(0)
+      if ((time(sim, timeunit(sim)) < endTime) & (v$stop != "stop")) invalidateLater(0)
       sim <<- spades(sim, debug = debug) # Run spades
     }
 
@@ -189,7 +187,7 @@ setMethod(
           }
         }
       }
-      end(sim) <- time(sim) + input$Steps
+      end(sim) <- time(sim, timeunit(sim)) + input$Steps
       sim <<- spades(sim, debug = debug)
     })
 
@@ -203,7 +201,7 @@ setMethod(
       }
     })
 
-    v <- reactiveValues(data = NULL, time = time(sim), end = end(sim), sliderUsed = FALSE)
+    v <- reactiveValues(data = NULL, time = time(sim, timeunit(sim)), end = end(sim, timeunit(sim)), sliderUsed = FALSE)
 
     # Button clicks
     observeEvent(input$oneTimestepSpaDESButton, {
@@ -245,8 +243,8 @@ setMethod(
       } else if (v$data == "reset") {
         simReset()
       }
-      v$time <- time(sim)
-      if (time(sim) >= endTime) {
+      v$time <- time(sim, timeunit(sim))
+      if (time(sim, timeunit(sim)) >= endTime) {
         v$end <- end(sim)
       }
       v$sliderUsed <- FALSE
@@ -267,7 +265,7 @@ setMethod(
           } else {
             objectDiagram(sim)
           }
-      })
+    })
 
     output$objectDiagramUI <- renderUI({
       if (v$time <= start(sim)) {
