@@ -1,6 +1,7 @@
 test_that("Plot 1 is not error-free", {
   library(sp)
   library(raster)
+  library(igraph)
 
   tmpdir <- file.path(tempdir(), "test_Plot1") %>% checkPath(create = TRUE)
   cwd <- getwd()
@@ -27,34 +28,32 @@ test_that("Plot 1 is not error-free", {
   clearPlot()
   expect_error(Plot(asdfd))
   clearPlot()
-  expect_that(Plot(landscape87654), testthat::not(throws_error()))
+  expect_silent(Plot(landscape87654))
 
   clearPlot()
-  expect_that(Plot(caribou87654), testthat::not(throws_error()))
+  expect_silent(Plot(caribou87654))
 
   # Test speedup > 0.1 for SpatialPoints
   clearPlot()
-  expect_that(Plot(caribou87654, speedup = 2), testthat::not(throws_error()))
+  #expect_that(Plot(caribou87654, speedup = 2))
+  expect_silent(Plot(caribou87654, speedup = 2))
 
   # can add a plot to the plotting window
   clearPlot()
-  expect_that(Plot(landscape87654), testthat::not(throws_error()))
-  expect_that(Plot(caribou87654, new = FALSE), testthat::not(throws_error()))
+  expect_silent(Plot(landscape87654))
+  expect_silent(Plot(caribou87654, new = FALSE))
 
   # Can add two maps with same name, if one is in a stack; they are given
   #  unique names based on object name
   clearPlot()
-  expect_that(Plot(landscape87654, caribou87654, DEM87654),
-              testthat::not(throws_error()))
+  expect_silent(Plot(landscape87654, caribou87654, DEM87654))
 
   # can mix stacks, rasters, SpatialPoint*
   clearPlot()
-  expect_that(Plot(landscape87654, habitatQuality87654, caribou87654),
-              testthat::not(throws_error()))
-
+  expect_silent(Plot(landscape87654, habitatQuality87654, caribou87654))
   # can mix stacks, rasters, SpatialPoint*, and SpatialPolygons*
   clearPlot()
-  expect_that(Plot(landscape87654, caribou87654), testthat::not(throws_error()))
+  expect_silent(Plot(landscape87654, caribou87654))
 
   Sr1 <- sp::Polygon(cbind(c(2, 4, 4, 1, 2), c(2, 3, 5, 4, 2)))
   Sr2 <- sp::Polygon(cbind(c(5, 4, 2, 5), c(2, 3, 2, 2)))
@@ -62,10 +61,9 @@ test_that("Plot 1 is not error-free", {
   Srs2 <- sp::Polygons(list(Sr2), "s2")
   SpP87654 <- sp::SpatialPolygons(list(Srs1, Srs2), 1:2)
   clearPlot()
-  expect_that(Plot(SpP87654), testthat::not(throws_error()))
+  expect_silent(Plot(SpP87654))
   clearPlot()
-  expect_that(Plot(landscape87654, caribou87654, SpP87654, new = TRUE),
-              testthat::not(throws_error()))
+  expect_silent(Plot(landscape87654, caribou87654, SpP87654, new = TRUE))
 
   Sr1 <- sp::Polygon(cbind(c(2, 4, 4, 1, 2), c(2, 3, 5, 4, 2)))
   Sr2 <- sp::Polygon(cbind(c(5, 4, 2, 5), c(2, 3, 2, 2)))
@@ -86,7 +84,9 @@ test_that("Plot 1 is not error-free", {
   Srs1 <- sp::Polygons(list(Sr1), "s1")
   Srs2 <- sp::Polygons(list(Sr2), "s2")
   SpP87 <- sp::SpatialPolygons(list(Srs1, Srs2), 1:2)
-  expect_that(Plot(SpP87, new = TRUE), testthat::not(throws_error()))
+   if (suppressWarnings(require(fastshp))) {
+    expect_silent(Plot(SpP87, new = TRUE))
+  }
 
   # test SpatialLines
   l1 <- cbind(c(10, 2, 30), c(30, 2, 2))
@@ -98,8 +98,9 @@ test_that("Plot 1 is not error-free", {
   S1 <- sp::Lines(list(Sl1, Sl1a), ID = "a")
   S2 <- sp::Lines(list(Sl2), ID = "b")
   Sl87654 <- sp::SpatialLines(list(S1, S2))
-  expect_that(Plot(Sl87654), testthat::not(throws_error()))
-
+   if (suppressWarnings(require(fastshp))) {
+    expect_silent(Plot(Sl87654))
+  }
   # Test polygon with > 1e3 points to test the speedup parameter
   r <- 1
   N <- 1000
@@ -117,66 +118,61 @@ test_that("Plot 1 is not error-free", {
   S1 <- sp::Lines(list(Sl1, Sl1a), ID = "a")
   S2 <- sp::Lines(list(Sl2), ID = "b")
   Sl87654 <- sp::SpatialLines(list(S1, S2))
-  expect_that(Plot(Sl87654, new = TRUE), testthat::not(throws_error()))
-
-  # test addTo
-  expect_that(Plot(SpP87654, addTo = "landscape87654$habitatQuality87654",
-                   gp = gpar(lwd = 2)), testthat::not(throws_error()))
+   if (suppressWarnings(require(fastshp))) {
+    expect_silent(Plot(Sl87654, new = TRUE))
+    # test addTo
+    expect_message(Plot(SpP87654, addTo = "landscape87654$habitatQuality87654"))
+  }
 
   # test various arguments
   clearPlot()
-  expect_that(Plot(caribou87654, new = TRUE, gpAxis = gpar(cex = 0.4), size = 1),
-              testthat::not(throws_error()))
+  expect_silent(Plot(caribou87654, new = TRUE, gpAxis = gpar(cex = 0.4), size = 1))
   clearPlot()
-  expect_that(Plot(DEM87654, gpText = gpar(cex = 0.4)),
-              testthat::not(throws_error()))
+  expect_silent(Plot(DEM87654, gpText = gpar(cex = 0.4)))
 
   # test colors
   clearPlot()
-  expect_that(Plot(DEM87654, cols = c("blue", "red")),
-              testthat::not(throws_error()))
+  expect_silent(Plot(DEM87654, cols = c("blue", "red")))
 
   # Should work with col as well as cols
   clearPlot()
-  expect_that(Plot(DEM87654, col = c("blue", "red")),
-              testthat::not(throws_error()))
-
+  expect_silent(Plot(DEM87654, col = c("blue", "red")))
 
   # test visualSqueeze
-  expect_that(Plot(DEM87654, visualSqueeze = 0.2, new = TRUE),
-              testthat::not(throws_error()))
-
+  expect_silent(Plot(DEM87654, visualSqueeze = 0.2, new = TRUE))
   # test speedup
   caribou87 <- sp::SpatialPoints(
     coords = cbind(x = stats::runif(1.1e3, 0, 10), y = stats::runif(1e1, 0, 10))
   )
-  expect_that(Plot(caribou87, speedup = 10, new = TRUE),
-              testthat::not(throws_error()))
-
+   if (suppressWarnings(require(fastshp))) {
+    expect_silent(Plot(caribou87, speedup = 10, new = TRUE))
+  }
   # test ggplot2 and hist -- don't work unless invoke global environment
   clearPlot()
   hist87654 <- hist(stats::rnorm(1e3), plot = FALSE)
-  expect_that(Plot(hist87654, new = TRUE), testthat::not(throws_error()))
+  expect_silent(Plot(hist87654, new = TRUE))
 
   # test ggplot2 and hist -- don't work unless invoke global environment
   clearPlot()
   ggplot87654 <- ggplot2::qplot(stats::rnorm(1e3), binwidth = 0.3,
                                 geom = "histogram")
-  expect_that(Plot(ggplot87654, new = TRUE), testthat::not(throws_error()))
+  expect_silent(Plot(ggplot87654, new = TRUE))
 
   # test rearrangements
-  expect_that(Plot(caribou87654, new = TRUE), testthat::not(throws_error()))
-  expect_that(Plot(DEM87654), testthat::not(throws_error()))
-  expect_that(Plot(habitatQuality87654), testthat::not(throws_error()))
+  expect_silent(Plot(caribou87654, new = TRUE))
+  expect_silent(Plot(DEM87654))
+  expect_silent(Plot(habitatQuality87654))
 
   testPlot <- Plot(habitatQuality87654)
-  expect_that(Plot(testPlot), testthat::not(throws_error()))
+  expect_silent(Plot(testPlot))
   expect_message(Plot(ls(), habitatQuality87654),
                  "Plot can only plot objects of class .spadesPlottables")
   expect_message(Plot(habitatQuality87654, addTo = "test"),
                  "Plot called with 'addTo' argument specified")
   expect_error(Plot(ls()), "Not a plottable object")
-  expect_that(rePlot(), testthat::not(throws_error()))
+  expect_silent(rePlot())
+
+  if (file.exists("Rplots.pdf")) file.remove("Rplots.pdf")
 })
 
 test_that("Unit tests for image content is not error-free", {
@@ -457,6 +453,7 @@ test_that("Plot 2 is not error-free", {
   r <- raster(system.file("external/test.grd", package = "raster"))
   message("These two plots should look similar")
   plot(r)
+
   dev()
 
   # 128 < vals < 1806
@@ -561,6 +558,8 @@ test_that("Plot 2 is not error-free", {
   Plot(pixelGroupMap, na.color = "white") # Should keep one dark Blue, rest white
 
   dev.off()
+
+  if (file.exists("Rplots.pdf")) file.remove("Rplots.pdf")
 })
 
 test_that("setColors is not error-free", {
@@ -611,11 +610,10 @@ test_that("setColors is not error-free", {
   })
   expect_true(identical(
     getColors(rasStack),
-    structure(list(ras1 = c("#FF0000FF", "#0000FFFF", "#00FF00FF"),
-                   ras2 = c("#A020F0FF", "#B757B3FF", "#CF8F78FF", "#E7C73CFF",
-                            "#FFFF00FF"),
-                   ras3 = c("#FFA500FF", "#FFBB00FF", "#FFD200FF", "#FFE800FF",
-                            "#FFFF00FF")),
-              .Names = c("ras1", "ras2", "ras3"))
+    structure(list(
+      ras1 = c("#FF0000FF", "#0000FFFF", "#00FF00FF"),
+      ras2 = c("#A020F0FF", "#B757B3FF", "#CF8F78FF", "#E7C73CFF", "#FFFF00FF"),
+      ras3 = c("#FFA500FF", "#FFBB00FF", "#FFD200FF", "#FFE800FF", "#FFFF00FF")),
+      .Names = c("ras1", "ras2", "ras3"))
   ))
 })
