@@ -15,7 +15,7 @@ test_that("defineModule correctly handles different inputs", {
     childModules = character(),
     authors = c(person(c("Alex", "M"), "Chubaty",
                        email = "alexander.chubaty@canada.ca",
-                       role=c("aut", "cre"))),
+                       role = c("aut", "cre"))),
     version = numeric_version("0.0.1"),
     spatialExtent = raster::extent(rep(NA_real_, 4)),
     timeframe = as.POSIXlt(c(NA, NA)),
@@ -28,7 +28,7 @@ test_that("defineModule correctly handles different inputs", {
     ),
     inputObjects = data.frame(
       objectName = "testInput", objectClass = "list", sourceURL = "",
-      other=NA_character_, stringsAsFactors=FALSE
+      other = NA_character_, stringsAsFactors = FALSE
     ),
     outputObjects = data.frame(
       objectName = "testOutput", objectClass = "list", other = NA_character_,
@@ -139,7 +139,7 @@ test_that("depsEdgeList and depsGraph work", {
   p_to <- c("caribouMovement", "fireSpread")
   p_objName <- c("landscape", "landscape")
   p_objClass <- c("RasterStack", "RasterStack")
-  p_ <- data.table(
+  p_ <- data.table::data.table(
     from = p_from, to = p_to, objName = p_objName, objClass = p_objClass
   )
 
