@@ -84,11 +84,10 @@ test_that("simulation runs with simInit and spades", {
   expect_equivalent(mySim$caribou$y, pos_y)
 })
 
-
 test_that("spades calls with different signatures don't work", {
   library(igraph); on.exit(detach("package:igraph"))
 
-  a = simInit()
+  a <- simInit()
   expect_silent(spades(a))
   expect_output(spades(a, debug = TRUE), "Completed Events")
   expect_silent(spades(a, .plotInitialTime = NA))
@@ -96,4 +95,27 @@ test_that("spades calls with different signatures don't work", {
   expect_output(spades(a, debug = TRUE, .plotInitialTime = NA), "Completed Events")
   expect_output(spades(a, debug = TRUE, .saveInitialTime = NA), "Completed Events")
 
+  if (interactive()) {
+    expect_output(spades(a, progress = "text", debug = TRUE), "10%")
+    expect_output(spades(a, progress = "text", debug = TRUE), "20%")
+    expect_output(spades(a, progress = "text"), "..........| 100%")
+  }
+  expect_silent(spades(a, progress = FALSE))
+  expect_silent(spades(a, progress = "rr"))
+
+  paths(a)$cachePath <- file.path(tempdir(), "cache") %>% checkPath(create = TRUE)
+  expect_output(spades(a, cache = TRUE, debug = TRUE), "Completed Events")
+  expect_true(all(dir(paths(a)$cachePath) == c("backpack.db", "gallery")))
+  file.remove(dir(paths(a)$cachePath, full.names = TRUE, recursive = TRUE))
+
+  # test for system time ... in this case, the first time through loop is slow
+  #   because of writing cache to disk, not because of spades being slow.
+  #   SimList is empty.
+  for (i in 1:2) {
+    a <- simInit()
+    paths(a)$cachePath <- file.path(tempdir(), "cache") %>% checkPath(create = TRUE)
+    assign(paste0("st", i), system.time(spades(a, cache = TRUE)))
+  }
+  expect_gt(st1[1], st2[1])
+  file.remove(dir(paths(a)$cachePath, full.names = TRUE, recursive = TRUE))
 })
